#
# spec file for package tumbler
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
%bcond_with libffmpegthumbnailer
%define libname libtumbler-1-0

Name:           tumbler
Version:        4.20.0
Release:        1.3
Summary:        Thumbnail Management for Xfce
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Graphics/Other
URL:            https://docs.xfce.org/xfce/thunar/tumbler
Source:         https://archive.xfce.org/src/xfce/%{name}/4.20/%{name}-%{version}.tar.bz2
Source1:        custom_thumbnailers.tar.gz
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gtk-doc) >= 1.9
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.1
# GdkPibuxf thumbnailer plugin
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.14
# FreeType2 font thumbnailer plugin
BuildRequires:  pkgconfig(freetype2)
# JPEG thumbnailer plugin with EXIF support
BuildRequires:  pkgconfig(libjpeg)
%if %{with libffmpegthumbnailer}
# ffmpeg video thumbnailer plugin
BuildRequires:  pkgconfig(libffmpegthumbnailer)
%endif
# gstreamer video thumbnailer plugin
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
# poppler PDF/PS thumbnailer plugin
BuildRequires:  pkgconfig(poppler-glib)
# ODF thumbnailer plugin
BuildRequires:  pkgconfig(libgsf-1)
# libopenraw thumbnailer plugin
BuildRequires:  libopenraw-devel
# freedesktop.org cache plugin
BuildRequires:  pkgconfig(libpng)
# OMDB cover plugin
BuildRequires:  pkgconfig(libcurl)
# EPUB Plugin
BuildRequires:  (pkgconfig(libgepub-0.6) or pkgconfig(libgepub-0.7))
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
# no matter what rpmlint says, we need the same lib-version
Requires:       %libname = %{version}
Recommends:     ffmpegthumbnailer

%description
Tumbler is a D-Bus service for applications to request thumbnails for various
URI schemes and MIME types. It is an implementation of the thumbnail management
D-Bus specification described on http://live.gnome.org/ThumbnailerSpec and
extensible through a plugin interface or via specialized thumbnailer services
implemented in accordance to the thumbnail management D-Bus specification.

%package -n %{name}-folder-thumbnailer
Summary:        Thumbnailer for folders
Group:          Productivity/Graphics/Other
Requires:       ImageMagick
Suggests:       thunar >= 1.8.2
Supplements:    (%{name} and thunar)

%description -n %{name}-folder-thumbnailer
A thumbnailer to show custom folder thumbnails in Thunar

%package -n %{name}-webp-thumbnailer
Summary:        Thumbnailer for WebP images
Group:          Productivity/Graphics/Other
Requires:       ImageMagick
Supplements:    (%{name} and ImageMagick)

%description -n %{name}-webp-thumbnailer
A thumbnailer for WebP images

%package -n %{libname}
Summary:        Tumbler Library
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}

%description -n %{libname}
This package provides the shared library component of tumbler.

%package devel
Summary:        Development Files for tumbler
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
This package contains the development files needed for developing tumbler
plugins.

%package doc
Summary:        Developer Documentation for tumbler
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the developer documentation for tumbler.

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{libname} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{libname})
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%autosetup
sed -i "s/libopenraw-gnome-1.0/libopenraw-gnome-0.1/g" acinclude.m4
pkg-config --exists libgepub-0.7 && sed -i "s/gepub-0.6/gepub-0.7/g" configure || true

tar -xzf %SOURCE1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
	--disable-static
%else
%configure
%endif
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

mkdir %{buildroot}%{_datadir}/thumbnailers
mv custom_thumbnailers/*.thumbnailer %{buildroot}%{_datadir}/thumbnailers/
mkdir %{buildroot}%{_bindir}
mv custom_thumbnailers/folder-thumbnailer %{buildroot}%{_bindir}/

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md
%dir %{_sysconfdir}/xdg/tumbler/
%config(noreplace) %{_sysconfdir}/xdg/tumbler/tumbler.rc
%dir %{_libdir}/tumbler-1
%{_libdir}/tumbler-1/tumblerd
%dir %{_libdir}/tumbler-1/plugins
%dir %{_libdir}/tumbler-1/plugins/cache
%{_libdir}/tumbler-1/plugins/cache/tumbler-xdg-cache.so
%{_libdir}/tumbler-1/plugins/cache/tumbler-cache-plugin.so
%{_libdir}/tumbler-1/plugins/tumbler-cover-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-desktop-thumbnailer.so
%if %{with libffmpegthumbnailer}
%{_libdir}/tumbler-1/plugins/tumbler-ffmpeg-thumbnailer.so
%endif
%{_libdir}/tumbler-1/plugins/tumbler-font-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-gst-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-jpeg-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-odf-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-pixbuf-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-poppler-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-raw-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-gepub-thumbnailer.so
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/*.service
%dir %{_datadir}/thumbnailers
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/*
%{_prefix}/lib/systemd/user/tumblerd.service

%files -n %{name}-folder-thumbnailer
%{_bindir}/folder-thumbnailer
%{_datadir}/thumbnailers/folder.thumbnailer

%files -n %{name}-webp-thumbnailer
%{_datadir}/thumbnailers/webp.thumbnailer

%files -n %{libname}
%license COPYING
%{_libdir}/libtumbler-1.so.*

%files lang -f %{name}.lang

%files devel
%{_includedir}/tumbler-1
%{_libdir}/pkgconfig/tumbler-1.pc
%{_libdir}/libtumbler-1.so

%files doc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/tumbler

%changelog
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0:
  * This release is part of the Xfce 4.20 platform release.
  * No changes since 4.19.3
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.3 [development release]:
  * xdg-cache: Fix string leak in xdg_cache_cache_cleanup
  * tumblerd: Fix string leaks in tumbler_manager_directory_changed
  * Translation Updates
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.2 [development release]:
  * build: Bump requirements for Xfce 4.20
  * Apply .clang-format file
  * Sort includes
  * tumbler: Add missing include guards
  * clang-format: Add file
  * plugins: Do not use g_file_is_native() to check for a valid path
  * gepub-thumbnailer: Emit error signal if file location is
    unsupported
  * gepub-thumbnailer: Fix create_from_mime()
  * gcc-analyzer: Fix -Wanalyzer-fd-leak
  * scan-build: Add false positive file
  * build: Use AM_DISTCHECK_CONFIGURE_FLAGS
  * xdg-cache: Fix and optimize xdg_cache_cache_is_thumbnail()
  * Do not use g_log_set_always_fatal()
  * Translation Updates
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.1
* Thu Nov 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Disambiguate thumbnailer signals
  * scheduler: Fix ready/error signal forwarding
  * desktop-thumbnailer: Use empty path to build cmdline if it is null
  * Update spec link in README
  * xdg-cache: Fix temporary file management when saving thumbnail
  * Add icon at 64px, clean up SVG metadata
* Mon Apr 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Fix memory leak in jpeg-thumbnailer
  * Fix memory leak in cover-thumbnailer
  * Fix previous commit
  * cover-thumbnailer: Fix deprecation warning
  * build: Let xdt-depends.m4 macros set GLib macros
  * Translation Updates
- Remove _service file
* Sat Dec 17 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * Performance improvements for the pixbuf-thumbnailer and the scheduler
  * Implement multiple overwrite options for the desktop-thumbnailer
  * Add support for the thumbnail sizes x-large and xx-large, which are
    very useful for high resolution displays
  * Tumbler and Thunar now support shared thumbnail repositories, like
    described in the freedesktop.org thumbnail specification. This feature
    can be used to produce thumbnails for a folder in advance, directly
    located near the pictures. Like that, the thumbnails don't need to be
    re-generated for each individual user.
  * tumbler.rc: Fix typo in explanatory comment
  * For the full list of changes from the 4.17 development branch see the
    packaged NEWS file.
- Restore RAW tumbnailer as issue with libopenraw 0.3 should be fixed
* Tue Oct 25 2022 Fabian Vogt <fvogt@suse.com>
- Exclude RAW thumbnailer on Leap 15.5+ as well
* Thu Sep 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Allow building against libgepub-0.7 (boo#1203644):
  + Adjust BuildRequires to work with libgepub-0.6 or libgepub-0.7.
  + Replace libgepub-0.6 occurences in configure script with
    libgepub-0.7 when libgepub 0.7 is present.
* Fri Aug 12 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.1
  * gst-thumbnailer: Add mime type check (gxo#xfce/tumbler#65)
  * desktop-thumbnailer: Guard against null path
  * Fix typo in gthread version (gxo#xfce/tumbler!14)
* Tue May 10 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Exclude RAW thumbnailer on Tumbleweed only to fix build on Leap
* Sat Apr 23 2022 Dominique Leuenberger <dleuenberger@suse.com>
- RelMgr override: do not package raw thumbnailer, as tumbler does
  not yet support openraw 0.3.
* Thu Oct 14 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Add Recommends: ffmpegthumbnailer
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  - Remove GLIB_CHECK_VERSION IFDEFs which are obsolete after glib bump
  - bump glib (and gio, gthread, etc) minimum to 2.50.0
  - Adjust bug report URL
  - Translation Updates
* Mon Nov 16 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.3.1
  - New plugin for epub books, using libgepub thumbnailer plugin
  - Fix documentation URL
  - Add README.md and EXTRA_DIST
  - Add new icon needed for xfce4-about-dialog
  - Translation Updates
* Mon Nov  2 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Remove hard dependency to Thunar 1.8.2. We use "Suggests" instead
  to make sure the correct version is picked while keeping a soft
  dependency.
* Sun Nov  1 2020 Alexei Podvalsky <avvissu@yandex.by>
- Weak dependencies: Use Supplements tag as recommended
  tumbler-folder-thumbnailer/tumbler-webp-thumbnailer dependencies
  for main package
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.3.0
  * Fix jpeg thumbnail orientation when fallback code is taken place
    (gxo#xfce/tumbler#28).
  * Use AC_CONFIG_MACRO_DIRS instead of AC_CONFIG_MACRO_DIR
  * Fix GTimeVal deprecation
  * Drop support of GLib < 2.32
  * Use guint32 for request handle and fix its further occurrences of 0
  * Implement Excludes paths in tumbler.rc
  * Translation Updates
* Thu Aug  6 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.2.9
  * This release addresses the issue described in gxo#xfce/tumbler#28
    and partially solved by the previous release 0.2.28.
    The issue now is completely solved by adding the correct
    orientation handling when fallback code for generating jpeg
    thumbnail takes place.
* Thu Mar 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Add support for WebP and custom folder thumbnails
  * Folder thumbnailer:
    https://docs.xfce.org/xfce/thunar/tumbler#customized_thumbnailer_for_folders
  * WebP thumbnailer: bxo#12528
* Sat Dec 21 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Updated to version 0.2.8
  * Fix thumbnail orientation (bxo#15011)
  * prepend $XDG_DATA_HOME/thumbnailers/ to thumbnailers directory
    (bxo#15858)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.2.7
  * Translation updates
- Cleaned up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.2.6
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.2.5
  * Translation updates
- Removed unneeded BuildRoot
* Wed Jun  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added OBS service file to fetch git master sources when needed
* Sun Jun  2 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Replace pkgconfig(liopenraw-gnome-1.0) BuildRequires with
  libopenraw-devel: the .pc file changed name between 0.0.x and
  0.1.x. Requiring the generic -devel name is easier than following
  upstreams namechanges.
- In case we build against libopenraw-gnome-0.1, update the build
  system to look for the right pc file using sed.
* Fri May 17 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 0.2.4
  - Check for sparse video files only on plugin side
  - Set Max file sizes
  - Add Fujifilm RAF support (bxo#14522)
  - Add more media types for audio cover thumbnails (bxo#12041)
  - Fix a typo in desktop-thumbnailer-provider.c (bxo#14925)
  - Update URLs in README and configure.ac
  - Fix g_type_class_add_private is deprecated
  - Bump glib version
  - Translation Updates
- Added bcond to build with sources from git master branch
- Switched to %%autosetup for simpler maintenance
- Switch urls to https://
- Cleaned up spec file
* Sat Sep 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 0.2.3
  - Test sparse files only for regular files (bxo#14693).
  - Fix uninitialized variable (bxo#14688)
  - Added check to avoid sparse files, that cause high cpu and
    memory load. (bxo#12259).
  - Use hash table to avoid scanning xdg user path twice when
    searching for desktop thumbnailers.
  - Close desktop thumbnailers directory when done from it.
  - Accept network paths in ffmpeg thumbnailer plugin.
  - Use pkg-config to find FreeType > 2.9.1.
  - Translation Updates
* Sun Apr  8 2018 seife+obs@b1-systems.com
- update to version 0.2.1
  - Handle 0 mtime threshold on Cleanup DBus method. This fixes
    running across all thumbnails that was causing very high I/O
    bandwidth usage when a file with a thumbnail gets deleted. (On
    dbus Cleanup method). bxo#9231
* Sat Nov 18 2017 seife+obs@b1-systems.com
- add explicit libtumbler versioned dependency to tumbler
* Fri Nov 17 2017 seife+obs@b1-systems.com
- update to version 0.2.0
  - Stable release of tumbler ported to GDbus
- 0.1.92:
  - Add support for loading thumbnailers from *.thumbnailer files
    (enhancement bug bxo#7475)
- 0.1.90:
  - Tumbler relies now on gdbus instead of dbus-glib
- 0.1.32:
  - bxo#13618 avoid loading specialized tumbnailers twice on system
    with duplicate path entry in $XDG_DATA_HOME (causes assertion
    failure)
  - bxo#13360 don't close GdkPixbufLoader on error (causes sigabrt)
  - bxo#13240 fix typo in exif tag for image height
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.1.31
  - use $XDG_CACHE_HOME/thumbnails as per spec change (bxo#10613)
  - move xdt m4 macros into separate directory
  - update xdt m4 macros
  - bump autotools requirements
  - fix IT_PROG_INTLTOOL warning
  - fix all m4 warnings
  - enable support for video/webm in ffmpeg thumbnailer plugin
    (bxo#10360)
  - translation updates
* Mon May 26 2014 gber@opensuse.org
- update to version 0.1.30
  - only enable keepalive in curl >= 7.25
  - support move/copy operations on directories in the cache
  - send the cache operation replies after they are completed
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 0.1.29
  - fix memory corruption on 64bit
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 0.1.28
  - set nice value of tumblerd to 19
  - fix rendering from pdfs with thumbnail
  - add more supported types for gst thumbnailer
  - some additional debug checks for bug #9766 and minor
    optimizations
  - fix deprecating warning with glib 2.36
  - include string.h
  - translation updates
- remove obsolete tumbler-libpng16.patch
* Fri Feb 15 2013 pgajdos@suse.com
- build also with libpng16
  * libpng16.patch
* Tue Jan 15 2013 gber@opensuse.org
- build the OMDB cover thumbnailer (although disabled by default
  for privacy reasons)
* Sat Jan 12 2013 gber@opensuse.org
- update to version 0.1.27
  - autotools updates
  - remove unmaintained translations
  - fix build when using -Wl,-z,defs
  - add cover-thumbnailer for movies
  - add config file system to control thumbnailing plugins
  - release thumbnail in gst thumbnailer
* Mon Dec 17 2012 gber@opensuse.org
- update to version 0.1.26
  - remove INSTALL
  - directly render the capture in the correct size
  - new gstreamer thumbnailer based on totem-thumbnailer
  - disable http and cdda schemes as well
  - add support for MPEG2 transport streams
  - rotate jpeg thumbnails
  - plug small leak
  - don't use collate to check strings
  - release lifecycle manager during early exit
  - don't abort with warnings in debug mode
  - clear 2.32 mutex memory leak
  - drop unneeded vfs schemes
  - work with an array to store the strings
  - don't use GString for a simple concat
  - make registry dump a bit smaller
  - don't use deprecated glib 2.32 API
  - rotate pixbuf loader images
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.1.25
  - remove some unused m4 macros
  - add or fix missing licenses
  - translation updates
* Sat Mar 31 2012 gber@opensuse.org
- update to version 0.1.24
  - link all plugins that use rint() against libm
  - call dbus_g_thread_init() to fix threading issues
  - add application/vnd.rn-realmedia to the ffmpeg plugin
  - explicitly link against gmodule
  - avoid accessing list elements after they have been freed
  - make sure to include PLATFORM flags everywhere
  - translation updates
* Tue Mar 27 2012 gber@opensuse.org
- split of -lang and shared library subpackages in order to comply
  with the shread library packaging policy
- enable ODF and RAW plugins and add the option to build the ffmpeg
  plugin
- correct dependencies
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Dec  4 2011 gber@opensuse.org
- update to version 0.1.23
  - fix generation of video images by starting the pipeline
  - add an ODF thumbnailer plugin
  - add support for OpenRaster images in the ODF thumbnailer
  - add a raw image thumbnailer plugin
  - exit the xdg thumbnailer nicely with corrupt png files
  - avoid huge thumbnails from libjpeg
  - optimize the pixbuf thumbnailer
  - bugfixes
  - translation updates
- dropped obsolete tumbler-0.1.22-fix-video-thumbnails.patch
* Tue Sep 27 2011 gber@opensuse.org
- added tumbler-0.1.22-fix-video-thumbnails.patch in order to fix
  the generation of video images by starting the pipeline
- build the gstreamer plugin now that it actually works
* Wed Sep 21 2011 gber@opensuse.org
- update to version 0.1.22
  - add coding style documentation
  - add a GStreamer-based thumbnailer for video thumbnails
  - avoid GdkPixbuf functions deprecated in poppler >= 0.17
  - translation updates
- dropped obsolete tumbler-poppler-0.18.patch,
  tumbler-poppler-0.18-bis.patch
* Tue Sep 20 2011 vuntz@opensuse.org
- Add tumbler-poppler-0.18.patch: fix build with poppler 0.17/0.18.
  Patch taken from git.
- Add tumbler-poppler-0.18-bis.patch: second part of the fix, not
  in git yet.
* Fri Feb 18 2011 gber@opensuse.org
- update to version 0.1.21
  - version bump to override incompatibly versioned packages for
    Maemo
  - quit tumbler after at least 5 minutes of inactivity
  - update to latest revision of the thumbnail management D-Bus
    specification where Cleanup() takes an array of base URIs
    instead of just one
  - translation updates
* Mon Jan 17 2011 gber@opensuse.org
- update to version 0.1.6
  - bugfixes
* Sun Dec 26 2010 gber@opensuse.org
- corrected license
- corrected groups
- improved summaries
- show compiler output
- remove unsupported locales
- enabled plugins:
  - GdkPixbuf thumbnailer
  - FreeType font thumbnailer
  - JPEG thumbnailer with EXIF support
  - PDF/PS thumbnailer plugin
  - Freedesktop.org cache
* Thu Dec  2 2010 prusnak@opensuse.org
- updated to 0.1.4
  - Use LGPL instead of GPL license headers in the library (bug #6781).
- updated to 0.1.3
  - Link plugins against libtumbler-1. Should fix builds with
  - -as-needed.
  - Move tumblerd into $libdir/tumbler-1.
  - Add support for arbitrary URI shemes in the poppler plugin.
  - Translation updates: Basque, Indonesian, Swedish, German, Russian,
    Galician, Uyghur, Chinese (Taiwan), Ukrainian, Finnish, Catalan
    (Valencian), Danish, Japanese, Kazakh, Italian, Portuguese,
- updated to 0.1.2
  - Add a new PDF/PostScript thumbnailer plugin based on poppler.
  - Add a new video thumbnailer plugin using libffmpegthumbnailer.
  - Handle missing URIs/MIME types in thumbnailer requests by reporting
    them back to the client application as an error.
  - Don't use dbus_connection_send from threads. Use g_idle_add()
    instead.
  - Improve tumblerd's startup significantly by optimizing the code
    dealing with updating the supported URI schemes and MIME types.
  - Avoid compiler warnings due to global name shadowing.
  - Translation updates: Traditional Chinese, Punjabi, Bengali, Sinhala,
    French, Chinese (China) and more.
* Wed Jan 13 2010 prusnak@suse.cz
- created package (version 0.1.1)
